<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
	<xsl:output method="xml"
							indent="yes"/>
  <xsl:param name="input"/>
	<xsl:template match="/">
		<xsl:result-document href="Validation_Result.html">
			<html>
				<head>
					<title>Validation Results</title>
					<style>
						body { font-family:verdana, arial, sans-serif; }
						th, td { vertical-align:top; text-align:left; }
					</style>
				</head>
				<body>
					<h1>
						<xsl:text>Validation Results</xsl:text> 
						<xsl:if test="string-length($input) != 0">
							<xsl:text> for </xsl:text>
							<span style="font-family:courier, monotype">
								<xsl:value-of select="$input"/>
							</span>
						</xsl:if>
					</h1>
					<xsl:apply-templates/>
				</body>
			</html>
		</xsl:result-document>
  </xsl:template>
  <xsl:template match="LearningObject">
    <xsl:variable name="N" select="MetaData/General/Title"/>
		<xsl:variable name="AL" select="number(MetaData/General/@AggregationLevel)"/>
		<table>
			<th>LearningObject</th>
			<th>Result</th>
			<xsl:for-each select="Content/LearningObject">
				<tr>
					<xsl:variable name="EmbeddN" select="MetaData/General/Title"/>
					<xsl:variable name="EmbeddAL" select="number(MetaData/General/@AggregationLevel)"/>
					<td>
						<xsl:value-of select="$EmbeddN"/>
					</td>
					<td>
						<xsl:choose>
							<xsl:when test="$AL - $EmbeddAL &lt; 0">
								<span style="color:red">Error!</span>
								<br/>
								<xsl:text>AggregationLevel of Embedded LearningObject &quot;</xsl:text>
								<xsl:value-of select="MetaData/General/Title"/>
								<xsl:text>&quot; (AggregationLevel=</xsl:text>
								<xsl:value-of select="$EmbeddAL"/>
								<xsl:text>)</xsl:text>
								<xsl:text> has to be less than or equal to the AggregationLevel of its parent LearningObject &quot;</xsl:text>
								<xsl:value-of select="$N"/>
								<xsl:text>&quot; (AggregationLevel=</xsl:text>
								<xsl:value-of select="$AL"/>
								<xsl:text>).</xsl:text>
							</xsl:when>
							<xsl:when test="$AL=2 and $EmbeddAL=2">
								<span style="color:red">Error!</span>
								<br/>
								<xsl:text>No LearningObjects with an AggregationLevel of &quot;</xsl:text>
								<xsl:value-of select="$EmbeddAL"/>
								<xsl:text>&quot; are allowed in Level </xsl:text>
								<xsl:value-of select="$AL"/>
								<xsl:text> LearningObjects</xsl:text>
							</xsl:when>
							<xsl:when test="$AL - $EmbeddAL &gt; 1">
								<span style="color:red">Error!</span>
								<br/>
								<xsl:text>Embedded LearningObjects with an AggregationLevel of &quot;1&quot; are only allowed in LearningObjects of AggregationLevel &quot;2&quot;.</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>No errors - LearningObject &quot;</xsl:text>
								<xsl:value-of select="$EmbeddN"/>
								<xsl:text>&quot; is correct.</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<xsl:apply-templates select="Content/LearningObject"/>
				</tr>
			</xsl:for-each>
		</table>
  </xsl:template>
</xsl:stylesheet>